from . import boardtype

import os
import pytest
import pyudev
import subprocess


@pytest.fixture
def tempdir():
    import tempfile
    with tempfile.TemporaryDirectory() as tmpdir:
        yield tmpdir


@pytest.mark.skipif(not boardtype.is_devkit(), reason="Not a devkit")
def test_sgtl5000():
    "Check if the sgtl5000 audio codec is there"
    out = subprocess.check_output(["aplay", "-l"])
    assert b"[Librem 5 Devkit]" in out


@pytest.mark.skipif(not boardtype.is_librem5(), reason="Not a phone")
def test_wm8962():
    "Check if the audio codec is there"
    out = subprocess.check_output(["aplay", "-l"])
    assert b"[Librem 5]" in out


def test_codec_and_modem_cards_exist():
    assert (os.path.exists('/sys/class/sound/card0'))
    assert (os.path.exists('/sys/class/sound/card1'))


def test_headphone_detection():
    "Check if we registered the headphone detection IRQ"
    f = open("/proc/interrupts")
    out = f.read()
    assert (" HP_DET" in out or "Headphone detection" in out)


def test_sound_output(tempdir):
    if boardtype.is_librem5():
        output = 'L5'
    else:
        output = 'Devkit'
    out = subprocess.run(["alsabat",
                          "-D",
                          "plughw:CARD={},DEV=0".format(output),
                          "-f",
                          "dat",
                          "--saveplay",
                          os.path.join(tempdir, 'default_dual.wav'),
                          "--standalone"],
                         capture_output=True)
    assert (b"Return value is 0" in out.stdout)
    assert (out.returncode == 0)


def test_modem_udev_tag():
    """Check that the modem got tagged correctly"""
    found = False
    context = pyudev.Context()
    for m in context.list_devices(subsystem='sound', SOUND_CLASS='modem'):
        assert (m.sys_path.startswith('/sys/devices/platform/sound-wwan/sound'))
        found = True
    assert (found is True)
