import shlex
import subprocess
import tempfile


def test_front():
    try:
        subprocess.check_call(['media-ctl', '-d', 'platform:30a90000.csi', '--set-v4l2', "\'csi\':0 [fmt:SGBRG10/1632x1224 colorspace:raw]"])
        subprocess.check_call(['media-ctl', '-d', 'platform:30a90000.csi', '--set-v4l2', "\'imx8mq-mipi-csi2 30a70000.csi\':0 [fmt:SGBRG10/1632x1224 colorspace:raw]"])
        subprocess.check_call(['media-ctl', '-d', 'platform:30a90000.csi', '--set-v4l2', "\'hi846 2-0020\':0 [fmt:SGBRG10/1632x1224 colorspace:raw]"])
        subprocess.check_call(['media-ctl', '-d', 'platform:30a90000.csi', '-l', "\'hi846 2-0020\':0 -> \'imx8mq-mipi-csi2 30a70000.csi\':0 [1]"])
    except subprocess.CalledProcessError as e:
        raise RuntimeError("media-ctl error: %s " % (e.returncode))

    try:
        subprocess.check_call(['v4l2-ctl', '--media-bus-info', 'platform:30a90000.csi', '--device', 'hi846 2-0020', '--set-ctrl=test_pattern=1'])
    except subprocess.CalledProcessError as e:
        raise RuntimeError("v4l2-ctl sensor setting error: %s " % (e.returncode))

    temp = tempfile.NamedTemporaryFile()
    hi846_format = ''
    if int(subprocess.getoutput('uname -r').split('.')[0]) >= 6:
        hi846_format = 'GB10'
    else:
        hi846_format = 'GB16'

    command = ('v4l2-ctl', '-d', "/dev/v4l/by-path/platform-30a90000.csi-video-index0", "--set-fmt-video=width=1632,height=1224,pixelformat=%s" % hi846_format, '--stream-mmap', '--stream-skip=3', '--stream-count=1', "--stream-to=%s" % temp.name)
    comp_data = bytearray([0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00])
    try:
        subprocess.check_call(command)
    except subprocess.CalledProcessError as e:
        subprocess.check_call(['v4l2-ctl', '--media-bus-info', 'platform:30a90000.csi', '--device', 'hi846 2-0020', '--set-ctrl=test_pattern=0'])
        raise RuntimeError("v4l2-ctl streaming error: %s " % (e.returncode))

    subprocess.check_call(['v4l2-ctl', '--media-bus-info', 'platform:30a90000.csi', '--device', 'hi846 2-0020', '--set-ctrl=test_pattern=0'])
    file = open("%s" % temp.name, "rb")
    assert(comp_data in file.read(30))
    file.close()


def test_big():
    def call(cmd):
        return subprocess.check_call(shlex.split(cmd))

    try:
        call('''media-ctl -d "platform:30b80000.csi" --entity "csi" --set-v4l2 "'csi':0 [fmt:SGRBG8/1052x780 colorspace:raw]"''')
        call('''media-ctl -d "platform:30b80000.csi" --entity "csi" --set-v4l2 "'imx8mq-mipi-csi2 30b60000.csi':0 [fmt:SGRBG8/1052x780 colorspace:raw]"''')
        call('''media-ctl -d "platform:30b80000.csi" --entity "csi" --set-v4l2 "'s5k3l6xx 3-002d':0 [fmt:SGRBG8/1052x780 colorspace:raw]"''')
        call('''media-ctl -d "platform:30b80000.csi" -l "'s5k3l6xx 3-002d':0 -> 'imx8mq-mipi-csi2 30b60000.csi':0 [1]"''')
    except subprocess.CalledProcessError as e:
        raise RuntimeError("media-ctl error: %s " % (e.returncode))

    try:
        # gray test pttern
        call('''v4l2-ctl --media-bus-info platform:30b80000.csi --device 's5k3l6xx 3-002d' --set-ctrl=test_pattern=5''')
    except subprocess.CalledProcessError as e:
        raise RuntimeError("v4l2-ctl sensor setting error: %s " % (e.returncode))

    try:
        with tempfile.NamedTemporaryFile(mode='rb') as tempf:
            call('''v4l2-ctl --device="/dev/v4l/by-path/platform-30b80000.csi-video-index0" --set-fmt-video=width=1052,height=780,pixelformat=GRBG --stream-mmap --stream-skip=3 --stream-count=1 --stream-to={}'''.format(tempf.name))

            comp_data = bytearray([0x10] * 0xc8550)
            assert(comp_data == tempf.read())
    except subprocess.CalledProcessError as e:
        raise RuntimeError("v4l2-ctl streaming error: %s " % (e.returncode))
    finally:
        call('''v4l2-ctl --media-bus-info platform:30b80000.csi --device 's5k3l6xx 3-002d' --set-ctrl=test_pattern=0''')
